XML Resume Library Installation

# XML Résumé Library Installation

The XML Résumé Library copyrighted, © 2000-2002 by Sean Kelly. See the copying conditions, license, and disclaimer.

## Installation Instructions

The XML Résumé Library is not your typically installed software system. Instead, it's an XML Document Type Definition (DTD) with three Extensible Stylesheet Language (XSL) transformation files.

See the main documentation for more details.